#===============================================================================
# pysmoove_summary.py
#===============================================================================

from argparse import ArgumentParser
from pysam import VariantFile

DHFFC_DEL = 0.7
DHFFC_DUP = 1.25
MSHQ = 3.0

def parse_arguments():
    parser = ArgumentParser(description='generate summary BED from VCF of SVs')
    parser.add_argument('vcf', metavar='<vcf>', help='VCF containing SVs')
    parser.add_argument('--dhffc-del', metavar='<float>', type=float,
        default=DHFFC_DEL, help=f'filter out deletions with DHFFC above this value [{DHFFC_DEL}]')
    parser.add_argument('--dhffc-dup', metavar='<float>', type=float,
        default=DHFFC_DUP, help=f'filter out deletions with DHFFC below this value [{DHFFC_DUP}]')
    parser.add_argument('--mshq', metavar='<float>', type=float,
        default=MSHQ, help=f'filter out hets with MSHQ below this value [{MSHQ}]')
    parser.add_argument('--header', action='store_true',
        help='include a header in output')
    return parser.parse_args()

def main():
    args = parse_arguments()
    if args.header:
        print('chrom', 'start', 'stop', 'type', 'size', 'samples',
                'genotypes', 'genes',  sep='\t')
    vcf_in = VariantFile(args.vcf)
    for rec in vcf_in.fetch():
        if rec.alts[0] in vcf_in.header.alts:
            if rec.info['SVTYPE'] == 'BND':
                continue
            samples = tuple(s for s in rec.samples
                            if not any(a is None for a in rec.samples[s].allele_indices)
                            if  sum(rec.samples[s].allele_indices) > 0)
            genotypes = tuple('/'.join(str(i) for i in rec.samples[s].allele_indices) for s in samples)
            if rec.info['SVTYPE'] == 'DEL':
                if all(rec.samples[s]['DHFFC'] > args.dhffc_del for s in samples):
                    continue
            if rec.info['SVTYPE'] == 'DUP':
                if all(rec.samples[s]['DHFFC'] < args.dhffc_dup for s in samples):
                    continue
            if '0/1' in genotypes:
                if rec.info['MSHQ'] < args.mshq:
                    continue
            genes = tuple(g.split('|')[0] for g in rec.info.get('smoove_gene', ())
                            if g.split('|')[1].startswith('gene'))
            if len(genes) == 0:
                genes = ('NA',)
            elif len(genes) > 4:
                genes = ('MANY',)
            print(rec.contig, rec.pos-1, rec.stop, rec.info['SVTYPE'],
                    abs(rec.info['SVLEN'][0]), ','.join(samples),
                    ','.join(genotypes), ','.join(genes), sep='\t')
        else:
            pass
            # print(rec.contig)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='pysmoove_summary',
    version='0.0.2',
    author='Anthony Aylward',
    author_email='aaylward@salk.edu',
    description='Summarize pysmoove SV calling VCF results in a BED-like format',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://gitlab.com/salk-tm/pysmoove_summary',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    install_requires=['pysam', 'pysmoove'],
    entry_points={
        'console_scripts': ['pysmoove-summary=pysmoove_summary.pysmoove_summary:main']
    },
    include_package_data=True
)
